#
# spec file for package conduit
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           conduit
BuildRequires:  dbus-1-python
BuildRequires:  fdupes
BuildRequires:  gnome-doc-utils-devel
BuildRequires:  intltool
BuildRequires:  pkg-config
BuildRequires:  python-goocanvas
BuildRequires:  python-vobject
BuildRequires:  translation-update-upstream
BuildRequires:  update-desktop-files
Summary:        A synchronization application for GNOME
License:        GPL-2.0
Group:          Productivity/Networking/Other
Version:        0.3.17
Release:        30.2
Source0:        %{name}-%{version}.tar.bz2
# PATCH-FIX-UPSTREAM bgo#565295 conduit-mozilla-browser.patch mboman@suse.de
Patch1:         conduit-mozilla-browser.patch
Url:            http://www.conduit-project.org
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires:       python-goocanvas
Recommends:     %{name}-lang
Recommends:     avahi
Recommends:     python-flickrapi
Recommends:     python-gdata
Recommends:     python-vobject
%{py_requires}
%if %suse_version <= 1110
%define python_sitelib %{py_sitedir}
%endif

%description
Conduit is a synchronization application for GNOME. It allows you to
synchronize your data between online web services (Gmail,
backpackit.com, etc) and your computer.

%lang_package
%prep
%setup -q
translation-update-upstream
%patch1 -p0

%build
%configure \
    --enable-nautilus-extension \
    --enable-eog-plugin \
    --enable-totem-plugin \
    --disable-scrollkeeper
make %{?_smp_mflags}

%install
%makeinstall
%find_lang %{name} %{?no_lang_C}
%suse_update_desktop_file -N conduit conduit GTK SyncUtility 
%fdupes $RPM_BUILD_ROOT

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-, root, root)
%doc AUTHORS NEWS README TODO
%dir %{_datadir}/gnome/
%dir %{_datadir}/gnome/help/
%dir %{_datadir}/gnome/help/%{name}/
%doc %{_datadir}/gnome/help/%{name}/C/
%dir %{_datadir}/omf/
%dir %{_datadir}/omf/%{name}/
%doc %{_datadir}/omf/%{name}/%{name}-C.omf
%{_bindir}/*
# We just list each module.  If the build requirements change and modules
# fail to build we should be able to catch it that way without implicitly
# listing too much here.
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/modules
%{_libdir}/%{name}/modules/AudioVideoConverterModule.*
%{_libdir}/%{name}/modules/DesktopWallpaperModule.*
%{_libdir}/%{name}/modules/GoogleBookmarksModule.*
%{_libdir}/%{name}/modules/NautilusBookmarksModule.*
%{_libdir}/%{name}/modules/BackpackModule
%{_libdir}/%{name}/modules/BansheeModule
%{_libdir}/%{name}/modules/BoxDotNetModule
%{_libdir}/%{name}/modules/ConverterModule.*
%{_libdir}/%{name}/modules/EvolutionModule
%{_libdir}/%{name}/modules/FacebookModule
%{_libdir}/%{name}/modules/FeedModule
%{_libdir}/%{name}/modules/FileModule
%{_libdir}/%{name}/modules/Firefox3Module
%{_libdir}/%{name}/modules/FlickrModule
%{_libdir}/%{name}/modules/FspotModule
%{_libdir}/%{name}/modules/GConfModule
%{_libdir}/%{name}/modules/GoogleModule
%{_libdir}/%{name}/modules/iPodModule
%{_libdir}/%{name}/modules/N800Module
%{_libdir}/%{name}/modules/NetworkModule
%{_libdir}/%{name}/modules/PhotoConverterModule.*
%{_libdir}/%{name}/modules/RhythmboxModule
%{_libdir}/%{name}/modules/ShutterflyModule
%{_libdir}/%{name}/modules/SmugMugModule
%{_libdir}/%{name}/modules/TomboyModule.*
%{_libdir}/%{name}/modules/ZotoModule
%{_libdir}/%{name}/modules/__init__.py*
%{_libdir}/pkgconfig/*.pc
%{python_sitelib}/%{name}
%{_datadir}/applications/*.desktop
%{_datadir}/%{name}
%dir %{_datadir}/omf/%{name}
%{_datadir}/dbus-1/services/org.conduit.service
# For some reason conduit has a 26x26 icon
%dir %{_datadir}/icons/hicolor/26x26
%dir %{_datadir}/icons/hicolor/26x26/apps
%{_datadir}/icons/hicolor/*/actions/*.png
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/icons/hicolor/*/status/*.png
%{_datadir}/icons/hicolor/*/apps/*.svg

%files lang -f %{name}.lang

%changelog
* Wed Jul  5 2017 mlin@suse.com
- Use python-vobject instead of vobject per python-vobject change in 42.3.
* Fri Mar  1 2013 dimstar@opensuse.org
- Spec-cleanup using format_spec_file service.
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Tue Dec 14 2010 vuntz@opensuse.org
- Own /usr/share/gnome and /usr/share/gnome/help to fix build.
* Fri Jun  4 2010 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Fri Jan 22 2010 vuntz@opensuse.org
- Update to version 0.3.17:
  + Fix dbus and configuration, install eog and nautilus extensions
    by default
  + Port to GtkBuilder
  + Use system gdata
  + UI improvements for hints
  + Autostart management from UI is improved
  + Use system installed flickrapi >= 1.2
  + Update pyfacebook
  + DB stability improvements
  + Fix configuration UI
  + Many translation updates
  + Many many bug fixes
  + Remove gnomevfs support
  + Support for Mac OSX added to Wallpaper Module
  + Support for Mac OSX added to Firefox 3 Module
- Add Recommends for python-gdata, to enable Google support and
  python-flickrapi for Flickr support.
* Tue Sep 29 2009 riggwelter@opensuse.org
- Add python-goocanvas to requires; vobject to recommends.
* Wed Aug 12 2009 dominique-obs@leuenberger.net
- Define new macros on openSUSE <= 11.1.
* Sun Aug  9 2009 coolo@novell.com
- use new python macros
* Sat Jun 27 2009 captain.magnus@opensuse.org
- Update to version 0.3.16:
  + New Configuration System
  + Support Firefox3 Bookmarks
  + Support Google Bookmarks
  + Support Nautilus Bookmarks
  + Add dataprovider for changing desktop wallpaper
  + Autostart capability can now be controlled from
    the preferences UI
  + Bugs fixed: bgo#510126, bgo#529327, bgo#529328, bgo#531250,
    bgo#548962, bgo#550641, bgo#552418, bgo#555404, bgo#556892,
    bgo#557589, bgo#557669, bgo#558176, bgo#559055, bgo#559599,
    bgo#561354, bgo#561554, bgo#561555, bgo#561557, bgo#562516,
    bgo#564020, bgo#564141, bgo#564144, bgo#564187, bgo#566588,
    bgo#568091, bgo#568293, bgo#568361, bgo#568362, bgo#568363,
    bgo#568372, bgo#568380, bgo#570434, bgo#571506, bgo#572005,
    bgo#572132, bgo#574907, bgo#547133
  + Translation updates
- Remove dbus-1-devel, gnome-common, gnome-python-desktop and
  perl-XML-Parser from BuildRequires
- Remove AutoReqProv. It's default
- Remove gnome-python-desktop, python-gdata, python-gnome-extras,
  python-goocanvas, vobject and dbus-1-python from Requires. Should
  be automatic
- Add "--enable-totem-plugin" to configure
- Don't package omf files in main package since it's in -lang
- Respin conduit-mozilla-browser.patch
- Remove conduit-fb-module-browser-fix.patch. Code changed
* Sun Jan 25 2009 vuntz@novell.com
- Call %%suse_update_desktop_file on all desktop files. Part of
  bnc#445728.
* Tue Dec 23 2008 mboman@suse.de
- Add patch conduit-mozilla-browser.patch. Fixes bgo#565295/bnc#461255
* Mon Oct 27 2008 vuntz@novell.com
- Don't require python-sqlite2 anymore: conduit can use the sqlite
  bindings shipped with newer python.
* Thu Oct 23 2008 maw@suse.de
- Update to version 0.3.15:
  + Bugs fixed: bgo#523181, bgo#555401, bgo#555403, bgo#555421,
    bgo#557105, and bgo#532854
  + Updated translations.
* Wed Sep 17 2008 maw@suse.de
- Require gnome-python-desktop to build and run, in lieu of
  evolution-python (bnc#418004).
* Wed Sep 10 2008 maw@suse.de
- Update to version 0.3.14:
  + Improve error logging and debug messages at startup
  + Improve network sync performance
  + Improve dataprovider config dialogs
  + Support ZOTO photos
  + Improve RSS feed enclosure support
  + Improve startup time
  + Improve conflict resolution
  + Improve iPod support
  + Port to GIO
  + Bugs fixed: bgo#510101, bgo#510127, bgo#517928, bgo#520748,
    bgo#520785, bgo#523551, bgo#523575, bgo#523579, bgo#523692,
    bgo#523915, bgo#524451, bgo#526292, bgo#527438, bgo#517536,
    bgo#530929, bgo#530979, bgo#530980, bgo#536400, bgo#536485,
    bgo#536485, bgo#516646, bgo#517877, bgo#525259, bgo#528221,
    bgo#530768, bgo#543366, bgo#543534, bgo#543685, bgo#543738,
    bgo#544712, bgo#545129, bgo#545728, bgo#509702, bgo#510279,
    bgo#526423, bgo#545464, bgo#545824, bgo#546478, bgo#547600,
    bgo#547604, bgo#547615, bgo#547617, bgo#547618, bgo#548404,
    bgo#548959, bgo#548960, bgo#548974, bgo#548989, bgo#549750,
    and bgo#549751
  + Updated translations
- Drop conduit-set-mozilla-five-home.patch, which has been
  upstreamed
- Respin conduit-fb-module-browser-fix.patch.
* Wed Apr 16 2008 crivera@suse.de
- Update conduit-set-mozilla-five-home.patch to set
  MOZILLA_FIVE_HOME to the xulrunner directory that matches
  the arch of gtkmozembed.so.  This fixes bnc#373972.
* Mon Mar 24 2008 crivera@suse.de
- Update to 0.3.9 and remove the backport patch.
- Removes the build dependency on dbus.
- Fixes the following bgo bugs:
  510124, 511691, 512230, 515328, 518592, 518704,
  519708, 521194, 521349, 522436.
* Wed Mar 19 2008 crivera@suse.de
- Remove the conduit-0.3.5 patches.  One of them is upstream
  already and the other is being replaced in favor of
  conduit-set-mozilla-five-home.patch. Add
  conduit-trunk-backports.patch with two small fixes from trunk.
  Add conduit-fb-module-browser-fix.patch to have the facebook
  module respect the browser setting.
* Wed Feb 20 2008 maw@suse.de
- Update to version 0.3.8:
  + Bugs fixed: bgo#508645, bgo#509021, bgo#510091, bgo#510094,
    bgo#510107, bgo#510129, bgo#510471, bgo#510523, bgo#511017,
    bgo#512379, bgo#512540, bgo#514589, bgo#514729, bgo#515270,
    bgo#515648, bgo#516410, bgo#516523, and bgo#516567
  + Update flickr, facebook, and Google internal libraries
  + Misc. improvements
  + Updated translations.
* Thu Jan 17 2008 jpr@suse.de
- Update to 0.3.6
  * Fix two-way Tomboy <--> folder sync
  * Fix two-way GConf <--> folder sync
  * Dont recreate the backpack API everytime we refresh
  * Fix Shutterfly to support image uploads and delete again (Jeremy Slater)
  * Fix attribution of Banshee dataprovider. It was contributed by Don Smith
  * Many fixes to image dataproviders
  * Add option to right click menu to enable 'Always Up To Date' sync
  * Run the dataprovider tests by default.
* Wed Jan 16 2008 jpr@suse.de
- Update to 0.3.5
  * Conduits embedded web browser should no longer crash.
  * Canceling synchronization should now work reliably and no longer
  block the GUI.
  * Correctly restore two-way sync setting.
  * Escape patch in folder scanner. Fixes webdav sync.
  * Improve handling of TempFiles
  * Remove dependence on xml.dom.ext (PyXML)
  * Remove dependence on python-avahi
  * The conflict expander (and window) should now move out of the
  way gracefully
  * Abstracted much of the uri handling to ease transition to gio/gvfs
  * Many fixes to work with python 2.4
  * Update to new backpack API
  * In memory mapping DB has been replace with sqlite based one. Should
  reduce memory usage during large sync's.
  * Restructure code layout to allow Conduit to be used as a library
  by other python programs.
  * Removed Gtk dependancy in core. Conduit command line can now be
  run without Gtk installed.
  * Added 'always up to date' infrastructure for automatic syncing.
  * Improved n800 support for syncing audio, video and photos to the
  device.
  * New AudioVideoConverter for transcoding media types (uses FFMPEG
  and/or mencoder)
  * Include Banshee support in configure.ac - from lool
  * Support data hashes in addition to mtimes as a means for detecting
  changes
  * Remove twisted dependency for network sync. Uses the built in
  python xmlrpc module
  * Use python logging module for better logging granularity
  * Make HAL easier to extend in dataprovider factories
  * Files that did not load correctly are shown in the preferences
  window to help debugging
  * Experimental maemo/hildon UI (Thomas)
  * Added iPod photos support
  * Write support in f-spot using its new dbus interface (Thomas)
  * Support tags in all datatypes (useful for images)
  * Incredible improvements in test coverage. 75%% lines of core
  code tested (including close to 100%% of the core sync engine)
  * RSS Feed source now supports video enclosures
  * Many many bug fixes as a result of test focus
- Add conduit-0.3.5-avahi-prototype.patch so avahi advertising works
- Add conduit-0.3.5-firefox-64bit.patch so firefox on x86_64 works
* Wed Dec  5 2007 maw@suse.de
- Spec file cleanups:
  + Improve various metadeta
  + Clean up the filelist.
* Thu Nov  1 2007 maw@suse.de
- Build require evolution-python.
* Thu Nov  1 2007 maw@suse.de
- Require evolution-python.
* Thu Nov  1 2007 maw@suse.de
- Require python-gdata.
* Thu Nov  1 2007 maw@suse.de
- Require python-sqlite2, not python-sqlite.
* Thu Nov  1 2007 maw@suse.de
- Build with nautilus and eog extensions
- Require python-sqlite and vobject.
* Thu Nov  1 2007 maw@suse.de
- Require python-goocanvas.
* Thu Nov  1 2007 maw@suse.de
- Remove 10.2 stuff for the time being.
* Thu Nov  1 2007 maw@suse.de
- Initial package.
